"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "size_constraint_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a SizeConstraintSet. You then use UpdateSizeConstraintSet to identify the part of a web request that you want AWS WAF to check for length, such as the length of the User-Agent header or the length of the query string. For example, you can create a SizeConstraintSet that matches any requests that have a query string that is longer than 100 bytes. You can then configure AWS WAF to reject those requests. To create and configure a SizeConstraintSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateSizeConstraintSet request.   Submit a CreateSizeConstraintSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateSizeConstraintSet request.   Submit an UpdateSizeConstraintSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the SizeConstraintSet. You can't change Name after you create a SizeConstraintSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.size_constraint_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.size_constraint_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="create_size_constraint_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, size_constraint_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a SizeConstraintSet. You can't delete a SizeConstraintSet if it's still used in any Rules or if it still includes any SizeConstraint objects (any filters). If you just want to remove a SizeConstraintSet from a Rule, use UpdateRule. To permanently delete a SizeConstraintSet, perform the following steps:   Update the SizeConstraintSet to remove filters, if any. For more information, see UpdateSizeConstraintSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteSizeConstraintSet request.   Submit a DeleteSizeConstraintSet request.

    Args:
        size_constraint_set_id(str): The SizeConstraintSetId of the SizeConstraintSet that you want to delete. SizeConstraintSetId is returned by CreateSizeConstraintSet and by ListSizeConstraintSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.size_constraint_set_.delete(
                ctx, size_constraint_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.size_constraint_set.delete size_constraint_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="delete_size_constraint_set",
        op_kwargs={
            "SizeConstraintSetId": size_constraint_set_id,
            "ChangeToken": change_token,
        },
    )


async def get(hub, ctx, size_constraint_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the SizeConstraintSet specified by SizeConstraintSetId.

    Args:
        size_constraint_set_id(str): The SizeConstraintSetId of the SizeConstraintSet that you want to get. SizeConstraintSetId is returned by CreateSizeConstraintSet and by ListSizeConstraintSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.size_constraint_set_.get(ctx, size_constraint_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.size_constraint_set.get size_constraint_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="get_size_constraint_set",
        op_kwargs={"SizeConstraintSetId": size_constraint_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of SizeConstraintSetSummary objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more SizeConstraintSets than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of SizeConstraintSets. For the second and subsequent ListSizeConstraintSets requests, specify the value of NextMarker from the previous response to get information about another batch of SizeConstraintSets. Defaults to None.
        limit(int, optional): Specifies the number of SizeConstraintSet objects that you want AWS WAF to return for this request. If you have more SizeConstraintSets objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of SizeConstraintSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.size_constraint_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.size_constraint_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="list_size_constraint_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, size_constraint_set_id: str, change_token: str, updates: List
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes SizeConstraint objects (filters) in a SizeConstraintSet. For each SizeConstraint object, you specify the following values:    Whether to insert or delete the object from the array. If you want to change a SizeConstraintSetUpdate object, you delete the existing object and add a new one.   The part of a web request that you want AWS WAF to evaluate, such as the length of a query string or the length of the User-Agent header.   Whether to perform any transformations on the request, such as converting it to lowercase, before checking its length. Note that transformations of the request body are not supported because the AWS resource forwards only the first 8192 bytes of your request to AWS WAF. You can only specify a single type of TextTransformation.   A ComparisonOperator used for evaluating the selected part of the request against the specified Size, such as equals, greater than, less than, and so on.   The length, in bytes, that you want AWS WAF to watch for in selected part of the request. The length is computed after applying the transformation.   For example, you can add a SizeConstraintSetUpdate object that matches web requests in which the length of the User-Agent header is greater than 100 bytes. You can then configure AWS WAF to block those requests. To create and configure a SizeConstraintSet, perform the following steps:   Create a SizeConstraintSet. For more information, see CreateSizeConstraintSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateSizeConstraintSet request.   Submit an UpdateSizeConstraintSet request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        size_constraint_set_id(str): The SizeConstraintSetId of the SizeConstraintSet that you want to update. SizeConstraintSetId is returned by CreateSizeConstraintSet and by ListSizeConstraintSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of SizeConstraintSetUpdate objects that you want to insert into or delete from a SizeConstraintSet. For more information, see the applicable data types:    SizeConstraintSetUpdate: Contains Action and SizeConstraint     SizeConstraint: Contains FieldToMatch, TextTransformation, ComparisonOperator, and Size     FieldToMatch: Contains Data and Type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.size_constraint_set_.update(
                ctx, size_constraint_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.size_constraint_set.update size_constraint_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="update_size_constraint_set",
        op_kwargs={
            "SizeConstraintSetId": size_constraint_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the set of key-value pairs (metadata) that are used to manage the resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource to get tags for.
        next_token(str, optional): The token that was returned from the previous API call, which would be used to return the next page of the list. The ListTagsforResource call lists all available tags in one call and does not use pagination. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="list_tags_for_resource",
        op_kwargs={
            "resourceArn": resource_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, repository_name: str, layer_digests: List, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Checks the availability of one or more image layers within a repository in a public registry. When an image is pushed to a repository, each image layer is checked to verify if it has been uploaded before. If it has been uploaded, then the image layer is skipped.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry that contains the image layers to check. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository that is associated with the image layers to check.
        layer_digests(List): The digests of the image layers to check.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.check_layer_availability.batch(
                ctx, repository_name=value, layer_digests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.check_layer_availability.batch repository_name=value, layer_digests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="batch_check_layer_availability",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "layerDigests": layer_digests,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    pull_request_id: str,
    approval_rule_name: str,
    new_rule_content: str,
    existing_rule_content_sha256: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the structure of an approval rule created specifically for a pull request. For example, you can change the number of required approvers and the approval pool for approvers.

    Args:
        pull_request_id(str): The system-generated ID of the pull request.
        approval_rule_name(str): The name of the approval rule you want to update.
        existing_rule_content_sha256(str, optional): The SHA-256 hash signature for the content of the approval rule. You can retrieve this information by using GetPullRequest. Defaults to None.
        new_rule_content(str): The updated content for the approval rule.  When you update the content of the approval rule, you can specify approvers in an approval pool in one of two ways:    CodeCommitApprovers: This option only requires an AWS account and a resource. It can be used for both IAM users and federated access users whose name matches the provided resource name. This is a very powerful option that offers a great deal of flexibility. For example, if you specify the AWS account 123456789012 and Mary_Major, all of the following are counted as approvals coming from that user:   An IAM user in the account (arn:aws:iam::123456789012:user/Mary_Major)   A federated user identified in IAM as Mary_Major (arn:aws:sts::123456789012:federated-user/Mary_Major)   This option does not recognize an active session of someone assuming the role of CodeCommitReview with a role session name of Mary_Major (arn:aws:sts::123456789012:assumed-role/CodeCommitReview/Mary_Major) unless you include a wildcard (*Mary_Major).    Fully qualified ARN: This option allows you to specify the fully qualified Amazon Resource Name (ARN) of the IAM user or role.    For more information about IAM ARNs, wildcards, and formats, see IAM Identifiers in the IAM User Guide. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.rule.content.update(
                ctx, pull_request_id=value, approval_rule_name=value, new_rule_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.rule.content.update pull_request_id=value, approval_rule_name=value, new_rule_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_pull_request_approval_rule_content",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "approvalRuleName": approval_rule_name,
            "existingRuleContentSha256": existing_rule_content_sha256,
            "newRuleContent": new_rule_content,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def apply(hub, ctx, load_balancer_name: str, security_groups: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates one or more security groups with your load balancer in a virtual private cloud (VPC). The specified security groups override the previously associated security groups. For more information, see Security Groups for Load Balancers in a VPC in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        security_groups(List): The IDs of the security groups to associate with the load balancer. Note that you cannot specify the name of the security group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.security_group_to_load_balancer.apply(
                ctx, load_balancer_name=value, security_groups=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.security_group_to_load_balancer.apply load_balancer_name=value, security_groups=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="apply_security_groups_to_load_balancer",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "SecurityGroups": security_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, cluster_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of the Scram Secrets associated with an Amazon MSK cluster.


        Args:
            cluster_arn(str):
    The arn of the cluster.
    .
            max_results(int, optional):
    The maxResults of the query.
    . Defaults to None.
            next_token(str, optional):
    The nextToken of the query.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.scram_secret.list_all(ctx, cluster_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.scram_secret.list_all cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_scram_secrets",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(hub, ctx, config: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Adds a notification channel to DevOps Guru. A notification channel is used to notify you about important DevOps Guru events, such as when an insight is generated.  If you use an Amazon SNS topic in another account, you must attach a policy to it that grants DevOps Guru permission to it notifications. DevOps Guru adds the required policy on your behalf to send notifications using Amazon SNS in your account. For more information, see Permissions for cross account Amazon SNS topics. If you use an Amazon SNS topic that is encrypted by an AWS Key Management Service customer-managed key (CMK), then you must add permissions to the CMK. For more information, see Permissions for AWS KMS–encrypted Amazon SNS topics.

    Args:
        config(Dict):  A NotificationChannelConfig object that specifies what type of notification channel to add. The one supported notification channel is Amazon Simple Notification Service (Amazon SNS). .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.notification_channel.add(ctx, config=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.notification_channel.add config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="add_notification_channel",
        op_kwargs={"Config": config},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of notification channels configured for DevOps Guru. Each notification channel is used to notify you when DevOps Guru generates an insight that contains information about how to improve your operations. The one supported notification channel is Amazon Simple Notification Service (Amazon SNS).

    Args:
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.notification_channel.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.notification_channel.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="list_notification_channels",
        op_kwargs={"NextToken": next_token},
    )


async def remove(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

     Removes a notification channel from DevOps Guru. A notification channel is used to notify you when DevOps Guru generates an insight that contains information about how to improve your operations.

    Args:
        id_(str):  The ID of the notification channel to be removed. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.notification_channel.remove(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.notification_channel.remove id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="remove_notification_channel",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(
    hub, ctx, organization_id: str, entity_id: str, grantee_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes permissions granted to a member (user or group).

    Args:
        organization_id(str): The identifier of the organization under which the member (user or group) exists.
        entity_id(str): The identifier of the member (user or group) that owns the mailbox.
        grantee_id(str): The identifier of the member (user or group) for which to delete granted permissions.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.permission.delete_multiple(
                ctx, organization_id=value, entity_id=value, grantee_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.permission.delete_multiple organization_id=value, entity_id=value, grantee_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_mailbox_permissions",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "GranteeId": grantee_id,
        },
    )


async def list_all(
    hub,
    ctx,
    organization_id: str,
    entity_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the mailbox permissions associated with a user, group, or resource mailbox.

    Args:
        organization_id(str): The identifier of the organization under which the user, group, or resource exists.
        entity_id(str): The identifier of the user, group, or resource for which to list mailbox permissions.
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.permission.list_all(
                ctx, organization_id=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.permission.list_all organization_id=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_mailbox_permissions",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put_multiple(
    hub,
    ctx,
    organization_id: str,
    entity_id: str,
    grantee_id: str,
    permission_values: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets permissions for a user, group, or resource. This replaces any pre-existing permissions.

    Args:
        organization_id(str): The identifier of the organization under which the user, group, or resource exists.
        entity_id(str): The identifier of the user, group, or resource for which to update mailbox permissions.
        grantee_id(str): The identifier of the user, group, or resource to which to grant the permissions.
        permission_values(List): The permissions granted to the grantee. SEND_AS allows the grantee to send email as the owner of the mailbox (the grantee is not mentioned on these emails). SEND_ON_BEHALF allows the grantee to send email on behalf of the owner of the mailbox (the grantee is not mentioned as the physical sender of these emails). FULL_ACCESS allows the grantee full access to the mailbox, irrespective of other folder-level permissions set on the mailbox.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.permission.put_multiple(
                ctx,
                organization_id=value,
                entity_id=value,
                grantee_id=value,
                permission_values=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.permission.put_multiple organization_id=value, entity_id=value, grantee_id=value, permission_values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="put_mailbox_permissions",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "GranteeId": grantee_id,
            "PermissionValues": permission_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    caller_id: str = None,
    configuration_set_name: str = None,
    content: Dict = None,
    destination_phone_number: str = None,
    origination_phone_number: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new voice message and send it to a recipient's phone number.

    Args:
        caller_id(str, optional): The phone number that appears on recipients' devices when they receive the message. Defaults to None.
        configuration_set_name(str, optional): The name of the configuration set that you want to use to send the message. Defaults to None.
        content(Dict, optional): An object that contains a voice message and information about the recipient that you want to send it to. Defaults to None.
        destination_phone_number(str, optional): The phone number that you want to send the voice message to. Defaults to None.
        origination_phone_number(str, optional): The phone number that Amazon Pinpoint should use to send the voice message. This isn't necessarily the phone number that appears on recipients' devices when they receive the message, because you can specify a CallerId parameter in the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.voice_message.send(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.voice_message.send
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="send_voice_message",
        op_kwargs={
            "CallerId": caller_id,
            "ConfigurationSetName": configuration_set_name,
            "Content": content,
            "DestinationPhoneNumber": destination_phone_number,
            "OriginationPhoneNumber": origination_phone_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "to_permission_set"


async def put(
    hub, ctx, instance_arn: str, permission_set_arn: str, inline_policy: str
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches an IAM inline policy to a permission set.  If the permission set is already referenced by one or more account assignments, you will need to call  ProvisionPermissionSet  after this action to apply the corresponding IAM policy updates to all assigned accounts.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set.
        inline_policy(str): The IAM inline policy to attach to a PermissionSet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.inline_policy.to_permission_set_.put(
                ctx, instance_arn=value, permission_set_arn=value, inline_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.inline_policy.to_permission_set.put instance_arn=value, permission_set_arn=value, inline_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="put_inline_policy_to_permission_set",
        op_kwargs={
            "InstanceArn": instance_arn,
            "PermissionSetArn": permission_set_arn,
            "InlinePolicy": inline_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    This operation provides status information on enabling or disabling AWS Health to work with your organization. To call this operation, you must sign in as an IAM user, assume an IAM role, or sign in as the root user (not recommended) in the organization's management account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.health_service.status_for_organization.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.health_service.status_for_organization.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_health_service_status_for_organization",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, encryption_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new security configuration. A security configuration is a set of security properties that can be used by Glue. You can use a security configuration to encrypt data at rest. For information about using security configurations in Glue, see Encrypting Data Written by Crawlers, Jobs, and Development Endpoints.

    Args:
        name(str): The name for the new security configuration.
        encryption_configuration(Dict): The encryption configuration for the new security configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.security_configuration.create(
                ctx, name=value, encryption_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.security_configuration.create name=value, encryption_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_security_configuration",
        op_kwargs={"Name": name, "EncryptionConfiguration": encryption_configuration},
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified security configuration.

    Args:
        name(str): The name of the security configuration to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.security_configuration.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.security_configuration.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_security_configuration",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a specified security configuration.

    Args:
        name(str): The name of the security configuration to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.security_configuration.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.security_configuration.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_security_configuration",
        op_kwargs={"Name": name},
    )


async def get_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all security configurations.

    Args:
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.security_configuration.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.security_configuration.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_security_configurations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets DNSSEC validation information for a specified resource.

    Args:
        resource_id(str): The ID of the virtual private cloud (VPC) for the DNSSEC validation status.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.dnssec_config.get(
                ctx, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.dnssec_config.get resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_dnssec_config",
        op_kwargs={"ResourceId": resource_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the configurations for DNSSEC validation that are associated with the current AWS account.

    Args:
        max_results(int, optional):  Optional: An integer that specifies the maximum number of DNSSEC configuration results that you want Amazon Route 53 to return. If you don't specify a value for MaxResults, Route 53 returns up to 100 configuration per page. Defaults to None.
        next_token(str, optional): (Optional) If the current AWS account has more than MaxResults DNSSEC configurations, use NextToken to get the second and subsequent pages of results. For the first ListResolverDnssecConfigs request, omit this value. For the second and subsequent requests, get the value of NextToken from the previous response and specify that value for NextToken in the request. Defaults to None.
        filters(List, optional): An optional specification to return a subset of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.dnssec_config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.dnssec_config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_dnssec_configs",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def update(hub, ctx, resource_id: str, validation: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing DNSSEC validation configuration. If there is no existing DNSSEC validation configuration, one is created.

    Args:
        resource_id(str): The ID of the virtual private cloud (VPC) that you're updating the DNSSEC validation status for.
        validation(str): The new value that you are specifying for DNSSEC validation for the VPC. The value can be ENABLE or DISABLE. Be aware that it can take time for a validation status change to be completed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.dnssec_config.update(
                ctx, resource_id=value, validation=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.dnssec_config.update resource_id=value, validation=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_resolver_dnssec_config",
        op_kwargs={"ResourceId": resource_id, "Validation": validation},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_name: str,
    inference_scheduler_name: str,
    data_upload_frequency: str,
    data_input_configuration: Dict,
    data_output_configuration: Dict,
    role_arn: str,
    client_token: str,
    data_delay_offset_in_minutes: int = None,
    server_side_kms_key_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a scheduled inference. Scheduling an inference is setting up a continuous real-time inference plan to analyze new measurement data. When setting up the schedule, you provide an S3 bucket location for the input data, assign it a delimiter between separate entries in the data, set an offset delay if desired, and set the frequency of inferencing. You must also provide an S3 bucket location for the output data.

    Args:
        model_name(str): The name of the previously trained ML model being used to create the inference scheduler. .
        inference_scheduler_name(str): The name of the inference scheduler being created. .
        data_delay_offset_in_minutes(int, optional):  A period of time (in minutes) by which inference on the data is delayed after the data starts. For instance, if you select an offset delay time of five minutes, inference will not begin on the data until the first data measurement after the five minute mark. For example, if five minutes is selected, the inference scheduler will wake up at the configured frequency with the additional five minute delay time to check the customer S3 bucket. The customer can upload data at the same frequency and they don't need to stop and restart the scheduler when uploading new data. . Defaults to None.
        data_upload_frequency(str):  How often data is uploaded to the source S3 bucket for the input data. The value chosen is the length of time between data uploads. For instance, if you select 5 minutes, Amazon Lookout for Equipment will upload the real-time data to the source bucket once every 5 minutes. This frequency also determines how often Amazon Lookout for Equipment starts a scheduled inference on your data. In this example, it starts once every 5 minutes. .
        data_input_configuration(Dict): Specifies configuration information for the input data for the inference scheduler, including delimiter, format, and dataset location. .
        data_output_configuration(Dict): Specifies configuration information for the output results for the inference scheduler, including the S3 location for the output. .
        role_arn(str): The Amazon Resource Name (ARN) of a role with permission to access the data source being used for the inference. .
        server_side_kms_key_id(str, optional): Provides the identifier of the AWS KMS customer master key (CMK) used to encrypt inference scheduler data by Amazon Lookout for Equipment. . Defaults to None.
        client_token(str):  A unique identifier for the request. If you do not set the client request token, Amazon Lookout for Equipment generates one. .
        tags(List, optional): Any tags associated with the inference scheduler. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.create(
                ctx,
                model_name=value,
                inference_scheduler_name=value,
                data_upload_frequency=value,
                data_input_configuration=value,
                data_output_configuration=value,
                role_arn=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.create model_name=value, inference_scheduler_name=value, data_upload_frequency=value, data_input_configuration=value, data_output_configuration=value, role_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="create_inference_scheduler",
        op_kwargs={
            "ModelName": model_name,
            "InferenceSchedulerName": inference_scheduler_name,
            "DataDelayOffsetInMinutes": data_delay_offset_in_minutes,
            "DataUploadFrequency": data_upload_frequency,
            "DataInputConfiguration": data_input_configuration,
            "DataOutputConfiguration": data_output_configuration,
            "RoleArn": role_arn,
            "ServerSideKmsKeyId": server_side_kms_key_id,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, inference_scheduler_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an inference scheduler that has been set up. Already processed output results are not affected.

    Args:
        inference_scheduler_name(str): The name of the inference scheduler to be deleted. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.delete(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.delete inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="delete_inference_scheduler",
        op_kwargs={"InferenceSchedulerName": inference_scheduler_name},
    )


async def describe(hub, ctx, inference_scheduler_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Specifies information about the inference scheduler being used, including name, model, status, and associated metadata

    Args:
        inference_scheduler_name(str): The name of the inference scheduler being described. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.describe(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.describe inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="describe_inference_scheduler",
        op_kwargs={"InferenceSchedulerName": inference_scheduler_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    inference_scheduler_name_begins_with: str = None,
    model_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all inference schedulers currently available for your account.

    Args:
        next_token(str, optional):  An opaque pagination token indicating where to continue the listing of inference schedulers. . Defaults to None.
        max_results(int, optional):  Specifies the maximum number of inference schedulers to list. . Defaults to None.
        inference_scheduler_name_begins_with(str, optional): The beginning of the name of the inference schedulers to be listed. . Defaults to None.
        model_name(str, optional): The name of the ML model used by the inference scheduler to be listed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="list_inference_schedulers",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "InferenceSchedulerNameBeginsWith": inference_scheduler_name_begins_with,
            "ModelName": model_name,
        },
    )


async def start(hub, ctx, inference_scheduler_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts an inference scheduler.

    Args:
        inference_scheduler_name(str): The name of the inference scheduler to be started. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.start(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.start inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="start_inference_scheduler",
        op_kwargs={"InferenceSchedulerName": inference_scheduler_name},
    )


async def stop(hub, ctx, inference_scheduler_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an inference scheduler.

    Args:
        inference_scheduler_name(str): The name of the inference scheduler to be stopped. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.stop(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.stop inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="stop_inference_scheduler",
        op_kwargs={"InferenceSchedulerName": inference_scheduler_name},
    )


async def update(
    hub,
    ctx,
    inference_scheduler_name: str,
    data_delay_offset_in_minutes: int = None,
    data_upload_frequency: str = None,
    data_input_configuration: Dict = None,
    data_output_configuration: Dict = None,
    role_arn: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates an inference scheduler.

    Args:
        inference_scheduler_name(str): The name of the inference scheduler to be updated. .
        data_delay_offset_in_minutes(int, optional): > A period of time (in minutes) by which inference on the data is delayed after the data starts. For instance, if you select an offset delay time of five minutes, inference will not begin on the data until the first data measurement after the five minute mark. For example, if five minutes is selected, the inference scheduler will wake up at the configured frequency with the additional five minute delay time to check the customer S3 bucket. The customer can upload data at the same frequency and they don't need to stop and restart the scheduler when uploading new data. Defaults to None.
        data_upload_frequency(str, optional): How often data is uploaded to the source S3 bucket for the input data. The value chosen is the length of time between data uploads. For instance, if you select 5 minutes, Amazon Lookout for Equipment will upload the real-time data to the source bucket once every 5 minutes. This frequency also determines how often Amazon Lookout for Equipment starts a scheduled inference on your data. In this example, it starts once every 5 minutes. . Defaults to None.
        data_input_configuration(Dict, optional):  Specifies information for the input data for the inference scheduler, including delimiter, format, and dataset location. . Defaults to None.
        data_output_configuration(Dict, optional):  Specifies information for the output results from the inference scheduler, including the output S3 location. . Defaults to None.
        role_arn(str, optional):  The Amazon Resource Name (ARN) of a role with permission to access the data source for the inference scheduler. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.scheduler.update(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.scheduler.update inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="update_inference_scheduler",
        op_kwargs={
            "InferenceSchedulerName": inference_scheduler_name,
            "DataDelayOffsetInMinutes": data_delay_offset_in_minutes,
            "DataUploadFrequency": data_upload_frequency,
            "DataInputConfiguration": data_input_configuration,
            "DataOutputConfiguration": data_output_configuration,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(
    hub, ctx, aws_account_id: str, data_set_id: str, ingestion_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an ongoing ingestion of data into SPICE.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): The ID of the dataset used in the ingestion.
        ingestion_id(str): An ID for the ingestion.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.ingestion.cancel(
                ctx, aws_account_id=value, data_set_id=value, ingestion_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.ingestion.cancel aws_account_id=value, data_set_id=value, ingestion_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="cancel_ingestion",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSetId": data_set_id,
            "IngestionId": ingestion_id,
        },
    )


async def create(
    hub, ctx, data_set_id: str, ingestion_id: str, aws_account_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates and starts a new SPICE ingestion on a dataset Any ingestions operating on tagged datasets inherit the same tags automatically for use in access control. For an example, see How do I create an IAM policy to control access to Amazon EC2 resources using tags? in the Amazon Web Services Knowledge Center. Tags are visible on the tagged dataset, but not on the ingestion resource.

    Args:
        data_set_id(str): The ID of the dataset used in the ingestion.
        ingestion_id(str): An ID for the ingestion.
        aws_account_id(str): The Amazon Web Services account; ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.ingestion.create(
                ctx, data_set_id=value, ingestion_id=value, aws_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.ingestion.create data_set_id=value, ingestion_id=value, aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_ingestion",
        op_kwargs={
            "DataSetId": data_set_id,
            "IngestionId": ingestion_id,
            "AwsAccountId": aws_account_id,
        },
    )


async def describe(
    hub, ctx, aws_account_id: str, data_set_id: str, ingestion_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a SPICE ingestion.

    Args:
        aws_account_id(str): The Amazon Web Services account; ID.
        data_set_id(str): The ID of the dataset used in the ingestion.
        ingestion_id(str): An ID for the ingestion.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.ingestion.describe(
                ctx, aws_account_id=value, data_set_id=value, ingestion_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.ingestion.describe aws_account_id=value, data_set_id=value, ingestion_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_ingestion",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DataSetId": data_set_id,
            "IngestionId": ingestion_id,
        },
    )


async def list_all(
    hub,
    ctx,
    data_set_id: str,
    aws_account_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the history of SPICE ingestions for a dataset.

    Args:
        data_set_id(str): The ID of the dataset used in the ingestion.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        aws_account_id(str): The Amazon Web Services account; ID.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.ingestion.list_all(
                ctx, data_set_id=value, aws_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.ingestion.list_all data_set_id=value, aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_ingestions",
        op_kwargs={
            "DataSetId": data_set_id,
            "NextToken": next_token,
            "AwsAccountId": aws_account_id,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dataset_name: str,
    dataset_schema: Dict,
    client_token: str,
    server_side_kms_key_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a container for a collection of data being ingested for analysis. The dataset contains the metadata describing where the data is and what the data actually looks like. In other words, it contains the location of the data source, the data schema, and other information. A dataset also contains any tags associated with the ingested data.

    Args:
        dataset_name(str): The name of the dataset being created. .
        dataset_schema(Dict): A JSON description of the data that is in each time series dataset, including names, column names, and data types. .
        server_side_kms_key_id(str, optional): Provides the identifier of the AWS KMS customer master key (CMK) used to encrypt dataset data by Amazon Lookout for Equipment. . Defaults to None.
        client_token(str):  A unique identifier for the request. If you do not set the client request token, Amazon Lookout for Equipment generates one. .
        tags(List, optional): Any tags associated with the ingested data described in the dataset. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.dataset.create(
                ctx, dataset_name=value, dataset_schema=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.dataset.create dataset_name=value, dataset_schema=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="create_dataset",
        op_kwargs={
            "DatasetName": dataset_name,
            "DatasetSchema": dataset_schema,
            "ServerSideKmsKeyId": server_side_kms_key_id,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, dataset_name: str) -> None:
    r"""
    **Autogenerated function**

     Deletes a dataset and associated artifacts. The operation will check to see if any inference scheduler or data ingestion job is currently using the dataset, and if there isn't, the dataset, its metadata, and any associated data stored in S3 will be deleted. This does not affect any models that used this dataset for training and evaluation, but does prevent it from being used in the future.

    Args:
        dataset_name(str): The name of the dataset to be deleted. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.dataset.delete(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.dataset.delete dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="delete_dataset",
        op_kwargs={"DatasetName": dataset_name},
    )


async def describe(hub, ctx, dataset_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information on a specified dataset such as the schema location, status, and so on.

    Args:
        dataset_name(str): The name of the dataset to be described. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.dataset.describe(ctx, dataset_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.dataset.describe dataset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="describe_dataset",
        op_kwargs={"DatasetName": dataset_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    dataset_name_begins_with: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all datasets currently available in your account, filtering on the dataset name.

    Args:
        next_token(str, optional):  An opaque pagination token indicating where to continue the listing of datasets. . Defaults to None.
        max_results(int, optional):  Specifies the maximum number of datasets to list. . Defaults to None.
        dataset_name_begins_with(str, optional): The beginning of the name of the datasets to be listed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.dataset.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.dataset.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="list_datasets",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "DatasetNameBeginsWith": dataset_name_begins_with,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(hub, ctx, workspace_id: str, workspace_state: str) -> Dict:
    r"""
    **Autogenerated function**

    Sets the state of the specified WorkSpace. To maintain a WorkSpace without being interrupted, set the WorkSpace state to ADMIN_MAINTENANCE. WorkSpaces in this state do not respond to requests to reboot, stop, start, rebuild, or restore. An AutoStop WorkSpace in this state is not stopped. Users cannot log into a WorkSpace in the ADMIN_MAINTENANCE state.

    Args:
        workspace_id(str): The identifier of the WorkSpace.
        workspace_state(str): The WorkSpace state.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.state.modify(
                ctx, workspace_id=value, workspace_state=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.state.modify workspace_id=value, workspace_state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_workspace_state",
        op_kwargs={"WorkspaceId": workspace_id, "WorkspaceState": workspace_state},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, email_address: str) -> None:
    r"""
    **Autogenerated function**

    Deprecated. Use the DeleteIdentity operation to delete email addresses and domains.

    Args:
        email_address(str): An email address to be removed from the list of verified addresses.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.verified_email_address.delete(ctx, email_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.verified_email_address.delete email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_verified_email_address",
        op_kwargs={"EmailAddress": email_address},
    )


async def list_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Deprecated. Use the ListIdentities operation to list the email addresses and domains associated with your account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.verified_email_address.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.verified_email_address.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ses", operation="list_verified_email_addresses", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "instance_type"


async def get_all(
    hub, ctx, outpost_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the instance types for the specified Outpost.

    Args:
        outpost_id(str): The ID of the Outpost.
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.outpost.outpost.instance_type_.get_all(ctx, outpost_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.outpost.outpost.instance_type.get_all outpost_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="outposts",
        operation="get_outpost_instance_types",
        op_kwargs={
            "OutpostId": outpost_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def stop(hub, ctx, secret_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the secret from replication and promotes the secret to a regional secret in the replica Region.

    Args:
        secret_id(str): Response to StopReplicationToReplica of a secret, based on the SecretId.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.replication_to_replica.stop(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.replication_to_replica.stop secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="stop_replication_to_replica",
        op_kwargs={"SecretId": secret_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def add(hub, ctx, arn: str, tag_list: List) -> None:
    r"""
    **Autogenerated function**

    Attaches tags to an existing Elasticsearch domain. Tags are a set of case-sensitive key value pairs. An Elasticsearch domain may have up to 10 tags. See  Tagging Amazon Elasticsearch Service Domains for more information.

    Args:
        arn(str):  Specify the ARN for which you want to add the tags.
        tag_list(List):  List of Tag that need to be added for the Elasticsearch domain. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.tags.add(ctx, arn=value, tag_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.tags.add arn=value, tag_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="add_tags",
        op_kwargs={"ARN": arn, "TagList": tag_list},
    )


async def list_(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns all tags for the given Elasticsearch domain.

    Args:
        arn(str):  Specify the ARN for the Elasticsearch domain to which the tags are attached that you want to view.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.tags.list(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.tags.list arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="es", operation="list_tags", op_kwargs={"ARN": arn}
    )


async def remove(hub, ctx, arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified set of tags from the specified Elasticsearch domain.

    Args:
        arn(str): Specifies the ARN for the Elasticsearch domain from which you want to delete the specified tags.
        tag_keys(List): Specifies the TagKey list which you want to remove from the Elasticsearch domain.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.tags.remove(ctx, arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.tags.remove arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="remove_tags",
        op_kwargs={"ARN": arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    pagination_token: str = None,
    tag_filters: List = None,
    resources_per_page: int = None,
    tags_per_page: int = None,
    resource_type_filters: List = None,
    include_compliance_details: bool = None,
    exclude_compliant_resources: bool = None,
    resource_arn_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all the tagged or previously tagged resources that are located in the specified Region for the AWS account. Depending on what information you want returned, you can also specify the following:    Filters that specify what tags and resource types you want returned. The response includes all tags that are associated with the requested resources.   Information about compliance with the account's effective tag policy. For more information on tag policies, see Tag Policies in the AWS Organizations User Guide.    This operation supports pagination, where the response can be sent in multiple pages. You should check the PaginationToken response parameter to determine if there are additional results available to return. Repeat the query, passing the PaginationToken response parameter value as an input to the next request until you recieve a null value. A null value for PaginationToken indicates that there are no more results waiting to be returned.

    Args:
        pagination_token(str, optional): Specifies a PaginationToken response value from a previous request to indicate that you want the next page of results. Leave this parameter empty in your initial request. Defaults to None.
        tag_filters(List, optional): Specifies a list of TagFilters (keys and values) to restrict the output to only those resources that have the specified tag and, if included, the specified value. Each TagFilter must contain a key with values optional. A request can include up to 50 keys, and each key can include up to 20 values.  Note the following when deciding how to use TagFilters:   If you don't specify a TagFilter, the response includes all resources that are currently tagged or ever had a tag. Resources that currently don't have tags are shown with an empty tag set, like this: "Tags": [].   If you specify more than one filter in a single request, the response returns only those resources that satisfy all filters.   If you specify a filter that contains more than one value for a key, the response returns resources that match any of the specified values for that key.   If you don't specify any values for a key, the response returns resources that are tagged with that key and any or no value. For example, for the following filters: filter1= {keyA,{value1}}, filter2={keyB,{value2,value3,value4}}, filter3= {keyC}:    GetResources({filter1}) returns resources tagged with key1=value1     GetResources({filter2}) returns resources tagged with key2=value2 or key2=value3 or key2=value4     GetResources({filter3}) returns resources tagged with any tag with the key key3, and with any or no value    GetResources({filter1,filter2,filter3}) returns resources tagged with (key1=value1) and (key2=value2 or key2=value3 or key2=value4) and (key3, any or no value)     . Defaults to None.
        resources_per_page(int, optional): Specifies the maximum number of results to be returned in each page. A query can return fewer than this maximum, even if there are more results still to return. You should always check the PaginationToken response value to see if there are more results. You can specify a minimum of 1 and a maximum value of 100. Defaults to None.
        tags_per_page(int, optional): AWS recommends using ResourcesPerPage instead of this parameter. A limit that restricts the number of tags (key and value pairs) returned by GetResources in paginated output. A resource with no tags is counted as having one tag (one key and value pair).  GetResources does not split a resource and its associated tags across pages. If the specified TagsPerPage would cause such a break, a PaginationToken is returned in place of the affected resource and its tags. Use that token in another request to get the remaining data. For example, if you specify a TagsPerPage of 100 and the account has 22 resources with 10 tags each (meaning that each resource has 10 key and value pairs), the output will consist of three pages. The first page displays the first 10 resources, each with its 10 tags. The second page displays the next 10 resources, each with its 10 tags. The third page displays the remaining 2 resources, each with its 10 tags. You can set TagsPerPage to a minimum of 100 items up to a maximum of 500 items. Defaults to None.
        resource_type_filters(List, optional): Specifies the resource types that you want included in the response. The format of each resource type is service[:resourceType]. For example, specifying a resource type of ec2 returns all Amazon EC2 resources (which includes EC2 instances). Specifying a resource type of ec2:instance returns only EC2 instances.  The string for each service name and resource type is the same as that embedded in a resource's Amazon Resource Name (ARN). Consult the AWS General Reference for the following: For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces. You can specify multiple resource types by using an array. The array can include up to 100 items. Note that the length constraint requirement applies to each resource type filter. . Defaults to None.
        include_compliance_details(bool, optional): Specifies whether to include details regarding the compliance with the effective tag policy. Set this to true to determine whether resources are compliant with the tag policy and to get details. Defaults to None.
        exclude_compliant_resources(bool, optional): Specifies whether to exclude resources that are compliant with the tag policy. Set this to true if you are interested in retrieving information on noncompliant resources only. You can use this parameter only if the IncludeComplianceDetails parameter is also set to true. Defaults to None.
        resource_arn_list(List, optional): Specifies a list of ARNs of resources for which you want to retrieve tag data. You can't specify both this parameter and any of the pagination parameters (ResourcesPerPage, TagsPerPage, PaginationToken) in the same request. If you specify both, you get an Invalid Parameter exception. If a resource specified by this parameter doesn't exist, it doesn't generate an error; it simply isn't included in the response. An ARN (Amazon Resource Name) uniquely identifies a resource. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces in the AWS General Reference. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resourcegroupstaggingapi.resource.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resourcegroupstaggingapi.resource.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resourcegroupstaggingapi",
        operation="get_resources",
        op_kwargs={
            "PaginationToken": pagination_token,
            "TagFilters": tag_filters,
            "ResourcesPerPage": resources_per_page,
            "TagsPerPage": tags_per_page,
            "ResourceTypeFilters": resource_type_filters,
            "IncludeComplianceDetails": include_compliance_details,
            "ExcludeCompliantResources": exclude_compliant_resources,
            "ResourceARNList": resource_arn_list,
        },
    )


async def tag(hub, ctx, resource_arn_list: List, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Applies one or more tags to the specified resources. Note the following:   Not all resources can have tags. For a list of services with resources that support tagging using this operation, see Services that support the Resource Groups Tagging API.   Each resource can have up to 50 tags. For other limits, see Tag Naming and Usage Conventions in the AWS General Reference.    You can only tag resources that are located in the specified AWS Region for the AWS account.   To add tags to a resource, you need the necessary permissions for the service that the resource belongs to as well as permissions for adding tags. For more information, see the documentation for each service.    Do not store personally identifiable information (PII) or other confidential or sensitive information in tags. We use tags to provide you with billing and administration services. Tags are not intended to be used for private or sensitive data.

    Args:
        resource_arn_list(List): Specifies the list of ARNs of the resources that you want to apply tags to. An ARN (Amazon Resource Name) uniquely identifies a resource. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces in the AWS General Reference.
        tags(Dict): Specifies a list of tags that you want to add to the specified resources. A tag consists of a key and a value that you define.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resourcegroupstaggingapi.resource.tag(
                ctx, resource_arn_list=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resourcegroupstaggingapi.resource.tag resource_arn_list=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resourcegroupstaggingapi",
        operation="tag_resources",
        op_kwargs={"ResourceARNList": resource_arn_list, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn_list: List, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified resources. When you specify a tag key, the action removes both that key and its associated value. The operation succeeds even if you attempt to remove tags from a resource that were already removed. Note the following:   To remove tags from a resource, you need the necessary permissions for the service that the resource belongs to as well as permissions for removing tags. For more information, see the documentation for the service whose resource you want to untag.   You can only tag resources that are located in the specified AWS Region for the calling AWS account.

    Args:
        resource_arn_list(List): Specifies a list of ARNs of the resources that you want to remove tags from. An ARN (Amazon Resource Name) uniquely identifies a resource. For more information, see Amazon Resource Names (ARNs) and AWS Service Namespaces in the AWS General Reference.
        tag_keys(List): Specifies a list of tag keys that you want to remove from the specified resources.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resourcegroupstaggingapi.resource.untag(
                ctx, resource_arn_list=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resourcegroupstaggingapi.resource.untag resource_arn_list=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resourcegroupstaggingapi",
        operation="untag_resources",
        op_kwargs={"ResourceARNList": resource_arn_list, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with a document classification job. Use this operation to get the status of a classification job.

    Args:
        job_id(str): The identifier that Amazon Comprehend generated for the job. The operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classification_job.describe(
                ctx, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classification_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_document_classification_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the documentation classification jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs on their names, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classification_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classification_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_document_classification_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    document_classifier_arn: str,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    job_name: str = None,
    client_request_token: str = None,
    volume_kms_key_id: str = None,
    vpc_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous document classification job. Use the operation to track the progress of the job.

    Args:
        job_name(str, optional): The identifier of the job. Defaults to None.
        document_classifier_arn(str): The Amazon Resource Name (ARN) of the document classifier to use to process the job.
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict): Specifies where to send the output files.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data.
        client_request_token(str, optional): A unique identifier for the request. If you do not set the client request token, Amazon Comprehend generates one. Defaults to None.
        volume_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.
        vpc_config(Dict, optional): Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for your document classification job. For more information, see Amazon VPC. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classification_job.start(
                ctx,
                document_classifier_arn=value,
                input_data_config=value,
                output_data_config=value,
                data_access_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classification_job.start document_classifier_arn=value, input_data_config=value, output_data_config=value, data_access_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="start_document_classification_job",
        op_kwargs={
            "JobName": job_name,
            "DocumentClassifierArn": document_classifier_arn,
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "ClientRequestToken": client_request_token,
            "VolumeKmsKeyId": volume_kms_key_id,
            "VpcConfig": vpc_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add tags to, or update the tag values of, an App Runner resource. A tag is a key-value pair.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to update tags for. It must be the ARN of an App Runner resource.
        tags(List): A list of tag key-value pairs to add or update. If a key is new to the resource, the tag is added with the provided value. If a key is already associated with the resource, the value of the tag is updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove tags from an App Runner resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to remove tags from. It must be the ARN of an App Runner resource.
        tag_keys(List): A list of tag keys that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, instance_type: str, elasticsearch_version: str, domain_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion. When modifying existing Domain, specify the  DomainName  to know what Limits are supported for modifying.

    Args:
        domain_name(str, optional):  DomainName represents the name of the Domain that we are trying to modify. This should be present only if we are querying for Elasticsearch  Limits  for existing domain. . Defaults to None.
        instance_type(str):  The instance type for an Elasticsearch cluster for which Elasticsearch  Limits  are needed. .
        elasticsearch_version(str):  Version of Elasticsearch for which  Limits  are needed. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.instance_type_.limit.describe_all(
                ctx, instance_type=value, elasticsearch_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.instance_type_.limit.describe_all instance_type=value, elasticsearch_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_elasticsearch_instance_type_limits",
        op_kwargs={
            "DomainName": domain_name,
            "InstanceType": instance_type,
            "ElasticsearchVersion": elasticsearch_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, sip_media_application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the logging configuration for the specified SIP media application.

    Args:
        sip_media_application_id(str): The SIP media application ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.logging_configuration.get(
                ctx, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.logging_configuration.get sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_sip_media_application_logging_configuration",
        op_kwargs={"SipMediaApplicationId": sip_media_application_id},
    )


async def put(
    hub,
    ctx,
    sip_media_application_id: str,
    sip_media_application_logging_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the logging configuration for the specified SIP media application.

    Args:
        sip_media_application_id(str): The SIP media application ID.
        sip_media_application_logging_configuration(Dict, optional): The actual logging configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.logging_configuration.put(
                ctx, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.logging_configuration.put sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_sip_media_application_logging_configuration",
        op_kwargs={
            "SipMediaApplicationId": sip_media_application_id,
            "SipMediaApplicationLoggingConfiguration": sip_media_application_logging_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, flow_arn: str, media_streams: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds media streams to an existing flow. After you add a media stream to a flow, you can associate it with a source and/or an output that uses the ST 2110 JPEG XS or CDI protocol.

    Args:
        flow_arn(str): The Amazon Resource Name (ARN) of the flow.
        media_streams(List): The media streams that you want to add to the flow.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.media_stream.add(
                ctx, flow_arn=value, media_streams=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.media_stream.add flow_arn=value, media_streams=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="add_flow_media_streams",
        op_kwargs={"FlowArn": flow_arn, "MediaStreams": media_streams},
    )


async def remove(hub, ctx, flow_arn: str, media_stream_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a media stream from a flow. This action is only available if the media stream is not associated with a source or output.

    Args:
        flow_arn(str): The Amazon Resource Name (ARN) of the flow.
        media_stream_name(str): The name of the media stream that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.media_stream.remove(
                ctx, flow_arn=value, media_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.media_stream.remove flow_arn=value, media_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="remove_flow_media_stream",
        op_kwargs={"FlowArn": flow_arn, "MediaStreamName": media_stream_name},
    )


async def update(
    hub,
    ctx,
    flow_arn: str,
    media_stream_name: str,
    attributes: Dict = None,
    clock_rate: int = None,
    description: str = None,
    media_stream_type: str = None,
    video_format: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing media stream.

    Args:
        attributes(Dict, optional): The attributes that you want to assign to the media stream. Defaults to None.
        clock_rate(int, optional): The sample rate (in Hz) for the stream. If the media stream type is video or ancillary data, set this value to 90000. If the media stream type is audio, set this value to either 48000 or 96000. Defaults to None.
        description(str, optional): Description. Defaults to None.
        flow_arn(str): The Amazon Resource Name (ARN) of the flow.
        media_stream_name(str): The name of the media stream that you want to update.
        media_stream_type(str, optional): The type of media stream. Defaults to None.
        video_format(str, optional): The resolution of the video. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.media_stream.update(
                ctx, flow_arn=value, media_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.media_stream.update flow_arn=value, media_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="update_flow_media_stream",
        op_kwargs={
            "Attributes": attributes,
            "ClockRate": clock_rate,
            "Description": description,
            "FlowArn": flow_arn,
            "MediaStreamName": media_stream_name,
            "MediaStreamType": media_stream_type,
            "VideoFormat": video_format,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Add tags to an accelerator resource.  For more information, see Tagging in AWS Global Accelerator in the AWS Global Accelerator Developer Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the Global Accelerator resource to add tags to. An ARN uniquely identifies a resource.
        tags(List): The tags to add to a resource. A tag consists of a key and a value that you define.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove tags from a Global Accelerator resource. When you specify a tag key, the action removes both that key and its associated value. The operation succeeds even if you attempt to remove tags from an accelerator that was already removed. For more information, see Tagging in AWS Global Accelerator in the AWS Global Accelerator Developer Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the Global Accelerator resource to remove tags from. An ARN uniquely identifies a resource.
        tag_keys(List): The tag key pairs that you want to remove from the specified resources.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a query logging policy. A query logging policy specifies the Resolver query logging operations and resources that you want to allow another AWS account to be able to use.

    Args:
        arn(str): The ARN of the query logging configuration that you want to get the query logging policy for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.policy.get(
                ctx, arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.policy.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_query_log_config_policy",
        op_kwargs={"Arn": arn},
    )


async def put(hub, ctx, arn: str, resolver_query_log_config_policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Specifies an AWS account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the account that you want to share rules with.
        resolver_query_log_config_policy(str): An AWS Identity and Access Management policy statement that lists the query logging configurations that you want to share with another AWS account and the operations that you want the account to be able to perform. You can specify the following operations in the Actions section of the statement:    route53resolver:AssociateResolverQueryLogConfig     route53resolver:DisassociateResolverQueryLogConfig     route53resolver:ListResolverQueryLogConfigAssociations     route53resolver:ListResolverQueryLogConfigs    In the Resource section of the statement, you specify the ARNs for the query logging configurations that you want to share with the account that you specified in Arn. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.query_log_config.policy.put(
                ctx, arn=value, resolver_query_log_config_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.query_log_config.policy.put arn=value, resolver_query_log_config_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="put_resolver_query_log_config_policy",
        op_kwargs={
            "Arn": arn,
            "ResolverQueryLogConfigPolicy": resolver_query_log_config_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds the specified tags to the specified resource. The supported resource types are users, routing profiles, queues, quick connects, and contact flows. For sample policies that use tags, see Amazon Connect Identity-Based Policy Examples in the Amazon Connect Administrator Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tags(Dict): One or more tags. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): The tag keys.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    instance_id: str,
    contact_flow_id: str,
    name: str,
    previous_contact_id: str = None,
    attributes: Dict = None,
    references: Dict = None,
    description: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a contact flow to start a new task.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        previous_contact_id(str, optional): The identifier of the previous chat, voice, or task contact. . Defaults to None.
        contact_flow_id(str): The identifier of the contact flow for initiating the tasks. To see the ContactFlowId in the Amazon Connect console user interface, on the navigation menu go to Routing, Contact Flows. Choose the contact flow. On the contact flow page, under the name of the contact flow, choose Show additional flow information. The ContactFlowId is the last part of the ARN, shown here in bold:  arn:aws:connect:us-west-2:xxxxxxxxxxxx:instance/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/contact-flow/846ec553-a005-41c0-8341-xxxxxxxxxxxx .
        attributes(Dict, optional): A custom key-value pair using an attribute map. The attributes are standard Amazon Connect attributes, and can be accessed in contact flows just like any other contact attributes. There can be up to 32,768 UTF-8 bytes across all key-value pairs per contact. Attribute keys can include only alphanumeric, dash, and underscore characters. Defaults to None.
        name(str): The name of a task that is shown to an agent in the Contact Control Panel (CCP).
        references(Dict, optional): A formatted URL that is shown to an agent in the Contact Control Panel (CCP). Defaults to None.
        description(str, optional): A description of the task that is shown to an agent in the Contact Control Panel (CCP). Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.task_contact.start(
                ctx, instance_id=value, contact_flow_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.task_contact.start instance_id=value, contact_flow_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="start_task_contact",
        op_kwargs={
            "InstanceId": instance_id,
            "PreviousContactId": previous_contact_id,
            "ContactFlowId": contact_flow_id,
            "Attributes": attributes,
            "Name": name,
            "References": references,
            "Description": description,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, auto_scaling_group_name: str, scheduled_update_group_actions: List
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates one or more scheduled scaling actions for an Auto Scaling group.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        scheduled_update_group_actions(List): One or more scheduled actions. The maximum number allowed is 50.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.put_scheduled_update_group_action.batch(
                ctx, auto_scaling_group_name=value, scheduled_update_group_actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.put_scheduled_update_group_action.batch auto_scaling_group_name=value, scheduled_update_group_actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="batch_put_scheduled_update_group_action",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScheduledUpdateGroupActions": scheduled_update_group_actions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(
    hub,
    ctx,
    type_: str = None,
    public_type_arn: str = None,
    publisher_id: str = None,
    type_name: str = None,
    type_name_alias: str = None,
    auto_update: bool = None,
    logging_config: Dict = None,
    execution_role_arn: str = None,
    version_bump: str = None,
    major_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Activates a public third-party extension, making it available for use in stack templates. For more information, see Using public extensions in the CloudFormation User Guide. Once you have activated a public third-party extension in your account and region, use SetTypeConfiguration to specify configuration properties for the extension. For more information, see Configuring extensions at the account level in the CloudFormation User Guide.

    Args:
        type_(str, optional): The extension type. Conditional: You must specify PublicTypeArn, or TypeName, Type, and PublisherId. Defaults to None.
        public_type_arn(str, optional): The Amazon Resource Number (ARN) of the public extension. Conditional: You must specify PublicTypeArn, or TypeName, Type, and PublisherId. Defaults to None.
        publisher_id(str, optional): The ID of the extension publisher. Conditional: You must specify PublicTypeArn, or TypeName, Type, and PublisherId. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify PublicTypeArn, or TypeName, Type, and PublisherId. Defaults to None.
        type_name_alias(str, optional): An alias to assign to the public extension, in this account and region. If you specify an alias for the extension, CloudFormation treats the alias as the extension type name within this account and region. You must use the alias to refer to the extension in your templates, API calls, and CloudFormation console. An extension alias must be unique within a given account and region. You can activate the same public resource multiple times in the same account and region, using different type name aliases. Defaults to None.
        auto_update(bool, optional): Whether to automatically update the extension in this account and region when a new minor version is published by the extension publisher. Major versions released by the publisher must be manually updated. The default is true. Defaults to None.
        logging_config(Dict, optional): Contains logging configuration information for an extension. Defaults to None.
        execution_role_arn(str, optional): The name of the IAM execution role to use to activate the extension. Defaults to None.
        version_bump(str, optional): Manually updates a previously-activated type to a new major or minor version, if available. You can also use this parameter to update the value of AutoUpdate.    MAJOR: CloudFormation updates the extension to the newest major version, if one is available.    MINOR: CloudFormation updates the extension to the newest minor version, if one is available.  . Defaults to None.
        major_version(int, optional): The major version of this extension you want to activate, if multiple major versions are available. The default is the latest major version. CloudFormation uses the latest available minor version of the major version selected. You can specify MajorVersion or VersionBump, but not both. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.activate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.activate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="activate_type",
        op_kwargs={
            "Type": type_,
            "PublicTypeArn": public_type_arn,
            "PublisherId": publisher_id,
            "TypeName": type_name,
            "TypeNameAlias": type_name_alias,
            "AutoUpdate": auto_update,
            "LoggingConfig": logging_config,
            "ExecutionRoleArn": execution_role_arn,
            "VersionBump": version_bump,
            "MajorVersion": major_version,
        },
    )


async def deactivate(
    hub, ctx, type_name: str = None, type_: str = None, arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deactivates a public extension that was previously activated in this account and region. Once deactivated, an extension cannot be used in any CloudFormation operation. This includes stack update operations where the stack template includes the extension, even if no updates are being made to the extension. In addition, deactivated extensions are not automatically updated if a new version of the extension is released.

    Args:
        type_name(str, optional): The type name of the extension, in this account and region. If you specified a type name alias when enabling the extension, use the type name alias. Conditional: You must specify either Arn, or TypeName and Type. Defaults to None.
        type_(str, optional): The extension type. Conditional: You must specify either Arn, or TypeName and Type. Defaults to None.
        arn(str, optional): The Amazon Resource Name (ARN) for the extension, in this account and region. Conditional: You must specify either Arn, or TypeName and Type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.deactivate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.deactivate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="deactivate_type",
        op_kwargs={"TypeName": type_name, "Type": type_, "Arn": arn},
    )


async def deregister(
    hub,
    ctx,
    arn: str = None,
    type_: str = None,
    type_name: str = None,
    version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Marks an extension or extension version as DEPRECATED in the CloudFormation registry, removing it from active use. Deprecated extensions or extension versions cannot be used in CloudFormation operations. To deregister an entire extension, you must individually deregister all active versions of that extension. If an extension has only a single active version, deregistering that version results in the extension itself being deregistered and marked as deprecated in the registry.  You cannot deregister the default version of an extension if there are other active version of that extension. If you do deregister the default version of an extension, the textensionype itself is deregistered as well and marked as deprecated.  To view the deprecation status of an extension or extension version, use DescribeType.

    Args:
        arn(str, optional): The Amazon Resource Name (ARN) of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_(str, optional): The kind of extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        version_id(str, optional): The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="deregister_type",
        op_kwargs={
            "Arn": arn,
            "Type": type_,
            "TypeName": type_name,
            "VersionId": version_id,
        },
    )


async def describe(
    hub,
    ctx,
    type_: str = None,
    type_name: str = None,
    arn: str = None,
    version_id: str = None,
    publisher_id: str = None,
    public_version_number: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about an extension that has been registered. If you specify a VersionId, DescribeType returns information about that specific extension version. Otherwise, it returns information about the default extension version.

    Args:
        type_(str, optional): The kind of extension.  Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        arn(str, optional): The Amazon Resource Name (ARN) of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        version_id(str, optional): The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered. If you specify a VersionId, DescribeType returns information about that specific extension version. Otherwise, it returns information about the default extension version. Defaults to None.
        publisher_id(str, optional): The publisher ID of the extension publisher. Extensions provided by Amazon are not assigned a publisher ID. Defaults to None.
        public_version_number(str, optional): The version number of a public third-party extension. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_type",
        op_kwargs={
            "Type": type_,
            "TypeName": type_name,
            "Arn": arn,
            "VersionId": version_id,
            "PublisherId": publisher_id,
            "PublicVersionNumber": public_version_number,
        },
    )


async def list_all(
    hub,
    ctx,
    visibility: str = None,
    provisioning_type: str = None,
    deprecated_status: str = None,
    type_: str = None,
    filters: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summary information about extension that have been registered with CloudFormation.

    Args:
        visibility(str, optional): The scope at which the extensions are visible and usable in CloudFormation operations. Valid values include:    PRIVATE: Extensions that are visible and usable within this account and region. This includes:   Private extensions you have registered in this account and region.   Public extensions that you have activated in this account and region.      PUBLIC: Extensions that are publicly visible and available to be activated within any Amazon account. This includes extensions from Amazon, as well as third-party publishers.   The default is PRIVATE. Defaults to None.
        provisioning_type(str, optional): For resource types, the provisioning behavior of the resource type. CloudFormation determines the provisioning type during registration, based on the types of handlers in the schema handler package submitted. Valid values include:    FULLY_MUTABLE: The resource type includes an update handler to process updates to the type during stack update operations.    IMMUTABLE: The resource type does not include an update handler, so the type cannot be updated and must instead be replaced during stack update operations.    NON_PROVISIONABLE: The resource type does not include create, read, and delete handlers, and therefore cannot actually be provisioned.   The default is FULLY_MUTABLE. Defaults to None.
        deprecated_status(str, optional): The deprecation status of the extension that you want to get summary information about. Valid values include:    LIVE: The extension is registered for use in CloudFormation operations.    DEPRECATED: The extension has been deregistered and can no longer be used in CloudFormation operations.   . Defaults to None.
        type_(str, optional): The type of extension. Defaults to None.
        filters(Dict, optional): Filter criteria to use in determining which extensions to return. If you specify a filter, CloudFormation ignores any specified Visibility value when returning the list of types. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. Defaults to None.
        next_token(str, optional): If the previous paginated request didn't return all of the remaining results, the response object's NextToken parameter value is set to a token. To retrieve the next set of results, call this action again and assign that token to the request object's NextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_types",
        op_kwargs={
            "Visibility": visibility,
            "ProvisioningType": provisioning_type,
            "DeprecatedStatus": deprecated_status,
            "Type": type_,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def publish(
    hub,
    ctx,
    type_: str = None,
    arn: str = None,
    type_name: str = None,
    public_version_number: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Publishes the specified extension to the CloudFormation registry as a public extension in this region. Public extensions are available for use by all CloudFormation users. For more information on publishing extensions, see Publishing extensions to make them available for public use in the CloudFormation CLI User Guide. To publish an extension, you must be registered as a publisher with CloudFormation. For more information, see RegisterPublisher.

    Args:
        type_(str, optional): The type of the extension. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        arn(str, optional): The Amazon Resource Number (ARN) of the extension. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        type_name(str, optional): The name of the extension. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        public_version_number(str, optional): The version number to assign to this version of the extension. Use the following format, and adhere to semantic versioning when assigning a version number to your extension:   MAJOR.MINOR.PATCH  For more information, see Semantic Versioning 2.0.0. If you do not specify a version number, CloudFormation increments the version number by one minor version release. The first time you publish a type, CloudFormation sets the version number to 1.0.0, regardless of the value you specify. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.publish(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.publish
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="publish_type",
        op_kwargs={
            "Type": type_,
            "Arn": arn,
            "TypeName": type_name,
            "PublicVersionNumber": public_version_number,
        },
    )


async def register(
    hub,
    ctx,
    type_name: str,
    schema_handler_package: str,
    type_: str = None,
    logging_config: Dict = None,
    execution_role_arn: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers an extension with the CloudFormation service. Registering an extension makes it available for use in CloudFormation templates in your account, and includes:   Validating the extension schema   Determining which handlers, if any, have been specified for the extension   Making the extension available for use in your account   For more information on how to develop extensions and ready them for registeration, see Creating Resource Providers in the CloudFormation CLI User Guide. You can have a maximum of 50 resource extension versions registered at a time. This maximum is per account and per region. Use DeregisterType to deregister specific extension versions if necessary. Once you have initiated a registration request using  RegisterType , you can use  DescribeTypeRegistration  to monitor the progress of the registration request. Once you have registered a private extension in your account and region, use SetTypeConfiguration to specify configuration properties for the extension. For more information, see Configuring extensions at the account level in the CloudFormation User Guide.

    Args:
        type_(str, optional): The kind of extension. Defaults to None.
        type_name(str): The name of the extension being registered. We recommend that extension names adhere to the following patterns:    For resource types, company_or_organization::service::type.   For modules, company_or_organization::service::type::MODULE.    The following organization namespaces are reserved and cannot be used in your extension names:    Alexa     AMZN     Amazon     AWS     Custom     Dev    .
        schema_handler_package(str): A url to the S3 bucket containing the extension project package that contains the neccessary files for the extension you want to register. For information on generating a schema handler package for the extension you want to register, see submit in the CloudFormation CLI User Guide.  The user registering the extension must be able to access the package in the S3 bucket. That is, the user needs to have GetObject permissions for the schema handler package. For more information, see Actions, Resources, and Condition Keys for Amazon S3 in the Identity and Access Management User Guide. .
        logging_config(Dict, optional): Specifies logging configuration information for an extension. Defaults to None.
        execution_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role for CloudFormation to assume when invoking the extension. For CloudFormation to assume the specified execution role, the role must contain a trust relationship with the CloudFormation service principle (resources.cloudformation.amazonaws.com). For more information on adding trust relationships, see Modifying a role trust policy in the Identity and Access Management User Guide. If your extension calls Amazon Web Services APIs in any of its handlers, you must create an  IAM execution role  that includes the necessary permissions to call those Amazon Web Services APIs, and provision that execution role in your account. When CloudFormation needs to invoke the resource type handler, CloudFormation assumes this execution role to create a temporary session token, which it then passes to the resource type handler, thereby supplying your resource type with the appropriate credentials. Defaults to None.
        client_request_token(str, optional): A unique identifier that acts as an idempotency key for this registration request. Specifying a client request token prevents CloudFormation from generating more than one version of an extension from the same registeration request, even if the request is submitted multiple times. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.register(
                ctx, type_name=value, schema_handler_package=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.register type_name=value, schema_handler_package=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="register_type",
        op_kwargs={
            "Type": type_,
            "TypeName": type_name,
            "SchemaHandlerPackage": schema_handler_package,
            "LoggingConfig": logging_config,
            "ExecutionRoleArn": execution_role_arn,
            "ClientRequestToken": client_request_token,
        },
    )


async def test(
    hub,
    ctx,
    arn: str = None,
    type_: str = None,
    type_name: str = None,
    version_id: str = None,
    log_delivery_bucket: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Tests a registered extension to make sure it meets all necessary requirements for being published in the CloudFormation registry.   For resource types, this includes passing all contracts tests defined for the type.   For modules, this includes determining if the module's model meets all necessary requirements.   For more information, see Testing your public extension prior to publishing in the CloudFormation CLI User Guide. If you do not specify a version, CloudFormation uses the default version of the extension in your account and region for testing. To perform testing, CloudFormation assumes the execution role specified when the type was registered. For more information, see RegisterType. Once you've initiated testing on an extension using TestType, you can use DescribeType to monitor the current test status and test status description for the extension. An extension must have a test status of PASSED before it can be published. For more information, see Publishing extensions to make them available for public use in the CloudFormation CLI User Guide.

    Args:
        arn(str, optional): The Amazon Resource Number (ARN) of the extension. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        type_(str, optional): The type of the extension to test. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        type_name(str, optional): The name of the extension to test. Conditional: You must specify Arn, or TypeName and Type. Defaults to None.
        version_id(str, optional): The version of the extension to test. You can specify the version id with either Arn, or with TypeName and Type. If you do not specify a version, CloudFormation uses the default version of the extension in this account and region for testing. Defaults to None.
        log_delivery_bucket(str, optional): The S3 bucket to which CloudFormation delivers the contract test execution logs. CloudFormation delivers the logs by the time contract testing has completed and the extension has been assigned a test type status of PASSED or FAILED. The user calling TestType must be able to access items in the specified S3 bucket. Specifically, the user needs the following permissions:   GetObject   PutObject   For more information, see Actions, Resources, and Condition Keys for Amazon S3 in the Amazon Web Services Identity and Access Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.init.test(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.init.test
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="test_type",
        op_kwargs={
            "Arn": arn,
            "Type": type_,
            "TypeName": type_name,
            "VersionId": version_id,
            "LogDeliveryBucket": log_delivery_bucket,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the last time a SIP OPTIONS ping was received from your SIP infrastructure for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.termination.health.get(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.termination.health.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_termination_health",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, account_id: str, job_id: str, priority: int) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing S3 Batch Operations job's priority. For more information, see S3 Batch Operations in the Amazon S3 User Guide.  Related actions include:    CreateJob     ListJobs     DescribeJob     UpdateJobStatus

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID for the job whose priority you want to update.
        priority(int): The priority you want to assign to this job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.priority.update(
                ctx, account_id=value, job_id=value, priority=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.priority.update account_id=value, job_id=value, priority=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="update_job_priority",
        op_kwargs={"AccountId": account_id, "JobId": job_id, "Priority": priority},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, pull_request_id: str, revision_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the approval states for a specified pull request. Approval states only apply to pull requests that have one or more approval rules applied to them.

    Args:
        pull_request_id(str): The system-generated ID for the pull request.
        revision_id(str): The system-generated ID for the pull request revision.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.state.get_all(
                ctx, pull_request_id=value, revision_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.state.get_all pull_request_id=value, revision_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_pull_request_approval_states",
        op_kwargs={"pullRequestId": pull_request_id, "revisionId": revision_id},
    )


async def update(
    hub, ctx, pull_request_id: str, revision_id: str, approval_state: str
) -> None:
    r"""
    **Autogenerated function**

    Updates the state of a user's approval on a pull request. The user is derived from the signed-in account when the request is made.

    Args:
        pull_request_id(str): The system-generated ID of the pull request.
        revision_id(str): The system-generated ID of the revision.
        approval_state(str): The approval state to associate with the user on the pull request.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.state.update(
                ctx, pull_request_id=value, revision_id=value, approval_state=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.state.update pull_request_id=value, revision_id=value, approval_state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_pull_request_approval_state",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "revisionId": revision_id,
            "approvalState": approval_state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create_multiple(hub, ctx, distribution_config_with_tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Create a new distribution with tags.

    Args:
        distribution_config_with_tags(Dict): The distribution's configuration information. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.with_tag.create_multiple(
                ctx, distribution_config_with_tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.with_tag.create_multiple distribution_config_with_tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_distribution_with_tags",
        op_kwargs={"DistributionConfigWithTags": distribution_config_with_tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def post(
    hub,
    ctx,
    bot_name: str,
    bot_alias: str,
    user_id: str,
    input_text: str,
    session_attributes: Dict = None,
    request_attributes: Dict = None,
    active_contexts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends user input to Amazon Lex. Client applications can use this API to send requests to Amazon Lex at runtime. Amazon Lex then interprets the user input using the machine learning model it built for the bot.   In response, Amazon Lex returns the next message to convey to the user an optional responseCard to display. Consider the following example messages:     For a user input "I would like a pizza", Amazon Lex might return a response with a message eliciting slot data (for example, PizzaSize): "What size pizza would you like?"     After the user provides all of the pizza order information, Amazon Lex might return a response with a message to obtain user confirmation "Proceed with the pizza order?".     After the user replies to a confirmation prompt with a "yes", Amazon Lex might return a conclusion statement: "Thank you, your cheese pizza has been ordered.".     Not all Amazon Lex messages require a user response. For example, a conclusion statement does not require a response. Some messages require only a "yes" or "no" user response. In addition to the message, Amazon Lex provides additional context about the message in the response that you might use to enhance client behavior, for example, to display the appropriate client user interface. These are the slotToElicit, dialogState, intentName, and slots fields in the response. Consider the following examples:    If the message is to elicit slot data, Amazon Lex returns the following context information:    dialogState set to ElicitSlot     intentName set to the intent name in the current context     slotToElicit set to the slot name for which the message is eliciting information     slots set to a map of slots, configured for the intent, with currently known values       If the message is a confirmation prompt, the dialogState is set to ConfirmIntent and SlotToElicit is set to null.    If the message is a clarification prompt (configured for the intent) that indicates that user intent is not understood, the dialogState is set to ElicitIntent and slotToElicit is set to null.     In addition, Amazon Lex also returns your application-specific sessionAttributes. For more information, see Managing Conversation Context.

    Args:
        bot_name(str): The name of the Amazon Lex bot.
        bot_alias(str): The alias of the Amazon Lex bot.
        user_id(str): The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. At runtime, each request must contain the userID field. To decide the user ID to use for your application, consider the following factors.   The userID field must not contain any personally identifiable information of the user, for example, name, personal identification numbers, or other end user personal information.   If you want a user to start a conversation on one device and continue on another device, use a user-specific identifier.   If you want the same user to be able to have two independent conversations on two different devices, choose a device-specific identifier.   A user can't have two independent conversations with two different versions of the same bot. For example, a user can't have a conversation with the PROD and BETA versions of the same bot. If you anticipate that a user will need to have conversation with two different versions, for example, while testing, include the bot alias in the user ID to separate the two conversations.  .
        session_attributes(Dict, optional): Application-specific information passed between Amazon Lex and a client application. For more information, see Setting Session Attributes. Defaults to None.
        request_attributes(Dict, optional): Request-specific information passed between Amazon Lex and a client application. The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:. For more information, see Setting Request Attributes. Defaults to None.
        input_text(str): The text that the user entered (Amazon Lex interprets this text).
        active_contexts(List, optional): A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request, If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_runtime.text.post(
                ctx, bot_name=value, bot_alias=value, user_id=value, input_text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_runtime.text.post bot_name=value, bot_alias=value, user_id=value, input_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-runtime",
        operation="post_text",
        op_kwargs={
            "botName": bot_name,
            "botAlias": bot_alias,
            "userId": user_id,
            "sessionAttributes": session_attributes,
            "requestAttributes": request_attributes,
            "inputText": input_text,
            "activeContexts": active_contexts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    marker: str = None,
    max_items: str = None,
    realtime_log_config_name: str = None,
    realtime_log_config_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of distributions that have a cache behavior that’s associated with the specified real-time log configuration. You can specify the real-time log configuration by its name or its Amazon Resource Name (ARN). You must provide at least one. If you provide both, CloudFront uses the name to identify the real-time log configuration to list distributions for. You can optionally specify the maximum number of items to receive in the response. If the total number of items in the list exceeds the maximum that you specify, or the default maximum, the response is paginated. To get the next page of items, send a subsequent request that specifies the NextMarker value from the current response as the Marker value in the subsequent request.

    Args:
        marker(str, optional): Use this field when paginating results to indicate where to begin in your list of distributions. The response includes distributions in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response. Defaults to None.
        max_items(str, optional): The maximum number of distributions that you want in the response. Defaults to None.
        realtime_log_config_name(str, optional): The name of the real-time log configuration whose associated distributions you want to list. Defaults to None.
        realtime_log_config_arn(str, optional): The Amazon Resource Name (ARN) of the real-time log configuration whose associated distributions you want to list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.by.realtime_log_config.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.by.realtime_log_config.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_distributions_by_realtime_log_config",
        op_kwargs={
            "Marker": marker,
            "MaxItems": max_items,
            "RealtimeLogConfigName": realtime_log_config_name,
            "RealtimeLogConfigArn": realtime_log_config_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a batch build.

    Args:
        id_(str): The identifier of the batch build to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_build_batch",
        op_kwargs={"id": id_},
    )


async def list_all(
    hub,
    ctx,
    filter_: Dict = None,
    max_results: int = None,
    sort_order: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the identifiers of your build batches in the current region.

    Args:
        filter_(Dict, optional): A BuildBatchFilter object that specifies the filters for the search. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        sort_order(str, optional): Specifies the sort order of the returned items. Valid values include:    ASCENDING: List the batch build identifiers in ascending order by identifier.    DESCENDING: List the batch build identifiers in descending order by identifier.  . Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous call to ListBuildBatches. This specifies the next item to return. To return the beginning of the list, exclude this parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_build_batches",
        op_kwargs={
            "filter": filter_,
            "maxResults": max_results,
            "sortOrder": sort_order,
            "nextToken": next_token,
        },
    )


async def retry(
    hub, ctx, id_: str = None, idempotency_token: str = None, retry_type: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Restarts a failed batch build. Only batch builds that have failed can be retried.

    Args:
        id_(str, optional): Specifies the identifier of the batch build to restart. Defaults to None.
        idempotency_token(str, optional): A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuildBatch request. The token is included in the RetryBuildBatch request and is valid for five minutes. If you repeat the RetryBuildBatch request with the same token, but change a parameter, AWS CodeBuild returns a parameter mismatch error. Defaults to None.
        retry_type(str, optional): Specifies the type of retry to perform. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.init.retry(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.init.retry
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="retry_build_batch",
        op_kwargs={
            "id": id_,
            "idempotencyToken": idempotency_token,
            "retryType": retry_type,
        },
    )


async def start(
    hub,
    ctx,
    project_name: str,
    secondary_sources_override: List = None,
    secondary_sources_version_override: List = None,
    source_version: str = None,
    artifacts_override: Dict = None,
    secondary_artifacts_override: List = None,
    environment_variables_override: List = None,
    source_type_override: str = None,
    source_location_override: str = None,
    source_auth_override: Dict = None,
    git_clone_depth_override: int = None,
    git_submodules_config_override: Dict = None,
    buildspec_override: str = None,
    insecure_ssl_override: bool = None,
    report_build_batch_status_override: bool = None,
    environment_type_override: str = None,
    image_override: str = None,
    compute_type_override: str = None,
    certificate_override: str = None,
    cache_override: Dict = None,
    service_role_override: str = None,
    privileged_mode_override: bool = None,
    build_timeout_in_minutes_override: int = None,
    queued_timeout_in_minutes_override: int = None,
    encryption_key_override: str = None,
    idempotency_token: str = None,
    logs_config_override: Dict = None,
    registry_credential_override: Dict = None,
    image_pull_credentials_type_override: str = None,
    build_batch_config_override: Dict = None,
    debug_session_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a batch build for a project.

    Args:
        project_name(str): The name of the project.
        secondary_sources_override(List, optional): An array of ProjectSource objects that override the secondary sources defined in the batch build project. Defaults to None.
        secondary_sources_version_override(List, optional): An array of ProjectSourceVersion objects that override the secondary source versions in the batch build project. Defaults to None.
        source_version(str, optional): The version of the batch build input to be built, for this build only. If not specified, the latest version is used. If specified, the contents depends on the source provider:  AWS CodeCommit  The commit ID, branch, or Git tag to use.  GitHub  The commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format pr/pull-request-ID (for example pr/25). If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.  Bitbucket  The commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch's HEAD commit ID is used. If not specified, the default branch's HEAD commit ID is used.  Amazon S3  The version ID of the object that represents the build input ZIP file to use.   If sourceVersion is specified at the project level, then this sourceVersion (at the build level) takes precedence.  For more information, see Source Version Sample with CodeBuild in the AWS CodeBuild User Guide. . Defaults to None.
        artifacts_override(Dict, optional): An array of ProjectArtifacts objects that contains information about the build output artifact overrides for the build project. Defaults to None.
        secondary_artifacts_override(List, optional): An array of ProjectArtifacts objects that override the secondary artifacts defined in the batch build project. Defaults to None.
        environment_variables_override(List, optional): An array of EnvironmentVariable objects that override, or add to, the environment variables defined in the batch build project. Defaults to None.
        source_type_override(str, optional): The source input type that overrides the source input defined in the batch build project. Defaults to None.
        source_location_override(str, optional): A location that overrides, for this batch build, the source location defined in the batch build project. Defaults to None.
        source_auth_override(Dict, optional): A SourceAuth object that overrides the one defined in the batch build project. This override applies only if the build project's source is BitBucket or GitHub. Defaults to None.
        git_clone_depth_override(int, optional): The user-defined depth of history, with a minimum value of 0, that overrides, for this batch build only, any previous depth of history defined in the batch build project. Defaults to None.
        git_submodules_config_override(Dict, optional): A GitSubmodulesConfig object that overrides the Git submodules configuration for this batch build. Defaults to None.
        buildspec_override(str, optional): A buildspec file declaration that overrides, for this build only, the latest one already defined in the build project. If this value is set, it can be either an inline buildspec definition, the path to an alternate buildspec file relative to the value of the built-in CODEBUILD_SRC_DIR environment variable, or the path to an S3 bucket. The bucket must be in the same AWS Region as the build project. Specify the buildspec file using its ARN (for example, arn:aws:s3:::my-codebuild-sample2/buildspec.yml). If this value is not provided or is set to an empty string, the source code must contain a buildspec file in its root directory. For more information, see Buildspec File Name and Storage Location. . Defaults to None.
        insecure_ssl_override(bool, optional): Enable this flag to override the insecure SSL setting that is specified in the batch build project. The insecure SSL setting determines whether to ignore SSL warnings while connecting to the project source code. This override applies only if the build's source is GitHub Enterprise. Defaults to None.
        report_build_batch_status_override(bool, optional): Set to true to report to your source provider the status of a batch build's start and completion. If you use this option with a source provider other than GitHub, GitHub Enterprise, or Bitbucket, an invalidInputException is thrown.   The status of a build triggered by a webhook is always reported to your source provider.  . Defaults to None.
        environment_type_override(str, optional): A container type for this batch build that overrides the one specified in the batch build project. Defaults to None.
        image_override(str, optional): The name of an image for this batch build that overrides the one specified in the batch build project. Defaults to None.
        compute_type_override(str, optional): The name of a compute type for this batch build that overrides the one specified in the batch build project. Defaults to None.
        certificate_override(str, optional): The name of a certificate for this batch build that overrides the one specified in the batch build project. Defaults to None.
        cache_override(Dict, optional): A ProjectCache object that specifies cache overrides. Defaults to None.
        service_role_override(str, optional): The name of a service role for this batch build that overrides the one specified in the batch build project. Defaults to None.
        privileged_mode_override(bool, optional): Enable this flag to override privileged mode in the batch build project. Defaults to None.
        build_timeout_in_minutes_override(int, optional): Overrides the build timeout specified in the batch build project. Defaults to None.
        queued_timeout_in_minutes_override(int, optional): The number of minutes a batch build is allowed to be queued before it times out. Defaults to None.
        encryption_key_override(str, optional): The AWS Key Management Service (AWS KMS) customer master key (CMK) that overrides the one specified in the batch build project. The CMK key encrypts the build output artifacts.  You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.   You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK's alias (using the format alias/<alias-name>). Defaults to None.
        idempotency_token(str, optional): A unique, case sensitive identifier you provide to ensure the idempotency of the StartBuildBatch request. The token is included in the StartBuildBatch request and is valid for five minutes. If you repeat the StartBuildBatch request with the same token, but change a parameter, AWS CodeBuild returns a parameter mismatch error. Defaults to None.
        logs_config_override(Dict, optional): A LogsConfig object that override the log settings defined in the batch build project. Defaults to None.
        registry_credential_override(Dict, optional): A RegistryCredential object that overrides credentials for access to a private registry. Defaults to None.
        image_pull_credentials_type_override(str, optional): The type of credentials AWS CodeBuild uses to pull images in your batch build. There are two valid values:   CODEBUILD  Specifies that AWS CodeBuild uses its own credentials. This requires that you modify your ECR repository policy to trust AWS CodeBuild's service principal.  SERVICE_ROLE  Specifies that AWS CodeBuild uses your build project's service role.    When using a cross-account or private registry image, you must use SERVICE_ROLE credentials. When using an AWS CodeBuild curated image, you must use CODEBUILD credentials. . Defaults to None.
        build_batch_config_override(Dict, optional): A BuildBatchConfigOverride object that contains batch build configuration overrides. Defaults to None.
        debug_session_enabled(bool, optional): Specifies if session debugging is enabled for this batch build. For more information, see Viewing a running build in Session Manager. Batch session debugging is not supported for matrix batch builds. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.init.start(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.init.start project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="start_build_batch",
        op_kwargs={
            "projectName": project_name,
            "secondarySourcesOverride": secondary_sources_override,
            "secondarySourcesVersionOverride": secondary_sources_version_override,
            "sourceVersion": source_version,
            "artifactsOverride": artifacts_override,
            "secondaryArtifactsOverride": secondary_artifacts_override,
            "environmentVariablesOverride": environment_variables_override,
            "sourceTypeOverride": source_type_override,
            "sourceLocationOverride": source_location_override,
            "sourceAuthOverride": source_auth_override,
            "gitCloneDepthOverride": git_clone_depth_override,
            "gitSubmodulesConfigOverride": git_submodules_config_override,
            "buildspecOverride": buildspec_override,
            "insecureSslOverride": insecure_ssl_override,
            "reportBuildBatchStatusOverride": report_build_batch_status_override,
            "environmentTypeOverride": environment_type_override,
            "imageOverride": image_override,
            "computeTypeOverride": compute_type_override,
            "certificateOverride": certificate_override,
            "cacheOverride": cache_override,
            "serviceRoleOverride": service_role_override,
            "privilegedModeOverride": privileged_mode_override,
            "buildTimeoutInMinutesOverride": build_timeout_in_minutes_override,
            "queuedTimeoutInMinutesOverride": queued_timeout_in_minutes_override,
            "encryptionKeyOverride": encryption_key_override,
            "idempotencyToken": idempotency_token,
            "logsConfigOverride": logs_config_override,
            "registryCredentialOverride": registry_credential_override,
            "imagePullCredentialsTypeOverride": image_pull_credentials_type_override,
            "buildBatchConfigOverride": build_batch_config_override,
            "debugSessionEnabled": debug_session_enabled,
        },
    )


async def stop(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running batch build.

    Args:
        id_(str): The identifier of the batch build to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.init.stop(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.init.stop id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="stop_build_batch",
        op_kwargs={"id": id_},
    )
